pub struct Checker;Expand description
A simple struct that contains checking functions
Implementations
Sourceimpl Checker
Checker struct implementation
impl Checker
Checker struct implementation
Sourcepub fn type_of<T: Any>(var: &dyn Any) -> bool
pub fn type_of<T: Any>(var: &dyn Any) -> bool
Verify the type of variable with a generic as a type.
This function takes a reference to any of your type and check if the type into the generic is the same that the type of your data.
use checking::Checker;
fn main() {
let result: bool = Checker::type_of::<i32>(&"test".to_string());
match result {
true => println!("Correct type"),
false => println!("Incorrect type"),
}
// Expected result: Correct type
}Sourcepub fn equals_to<T: PartialEq>(a: T, b: T) -> bool
pub fn equals_to<T: PartialEq>(a: T, b: T) -> bool
Executes a logical equal on both datas
All datas needs to derive PartialEq.
use checking::Checker;
#[derive(PartialEq)]
struct Test {
a: u8,
}
fn main() {
let a: Test = Test {
a: 2,
};
let b: Test = Test {
a: 8,
};
let result: bool = Checker::equals_to(a, b);
match result {
true => println!("Equal!"),
false => println!("Not equal"),
}
// Expected result: Equal!
}Auto Trait Implementations
impl Freeze for Checker
impl RefUnwindSafe for Checker
impl Send for Checker
impl Sync for Checker
impl Unpin for Checker
impl UnwindSafe for Checker